# RatingGroup


## Enum

* `BYBILLINGPERIOD` (value: `'ByBillingPeriod'`)

* `BYUSAGESTARTDATE` (value: `'ByUsageStartDate'`)

* `BYUSAGERECORD` (value: `'ByUsageRecord'`)

* `BYUSAGEUPLOAD` (value: `'ByUsageUpload'`)

* `BYGROUPID` (value: `'ByGroupId'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


